==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/VpcDhcpOptionsAssociationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin

import com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Provides a VPC DHCP Options Association resource.
 * ## Example Usage
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.ec2.VpcDhcpOptionsAssociation;
 * import com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var dnsResolver = new VpcDhcpOptionsAssociation("dnsResolver", VpcDhcpOptionsAssociationArgs.builder()
 *             .vpcId(aws_vpc.foo().id())
 *             .dhcpOptionsId(aws_vpc_dhcp_options.foo().id())
 *             .build());
 *     }
 * }
 * ```
 * ## Remarks
 * * You can only associate one DHCP Options Set to a given VPC ID.
 * * Removing the DHCP Options Association automatically sets AWS's `default` DHCP Options Set to the VPC.
 * ## Import
 * Using `pulumi import`, import DHCP associations using the VPC ID associated with the options. For example:
 * ```sh
 *  $ pulumi import aws:ec2/vpcDhcpOptionsAssociation:VpcDhcpOptionsAssociation imported vpc-0f001273ec18911b1
 * ```
 * @property dhcpOptionsId The ID of the DHCP Options Set to associate to the VPC.
 * @property vpcId The ID of the VPC to which we would like to associate a DHCP Options Set.
 */
public data class VpcDhcpOptionsAssociationArgs(
    public val dhcpOptionsId: Output<String>? = null,
    public val vpcId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs> {
    override fun toJava(): com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs =
        com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs.builder()
            .dhcpOptionsId(dhcpOptionsId?.applyValue({ args0 -> args0 }))
            .vpcId(vpcId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VpcDhcpOptionsAssociationArgs].
 */
@PulumiTagMarker
public class VpcDhcpOptionsAssociationArgsBuilder internal constructor() {
    private var dhcpOptionsId: Output<String>? = null

    private var vpcId: Output<String>? = null

    /**
     * @param value The ID of the DHCP Options Set to associate to the VPC.
     */
    @JvmName("phwrpwdlkvjiqiqm")
    public suspend fun dhcpOptionsId(`value`: Output<String>) {
        this.dhcpOptionsId = value
    }

    /**
     * @param value The ID of the VPC to which we would like to associate a DHCP Options Set.
     */
    @JvmName("tkweitobrxxekayv")
    public suspend fun vpcId(`value`: Output<String>) {
        this.vpcId = value
    }

    /**
     * @param value The ID of the DHCP Options Set to associate to the VPC.
     */
    @JvmName("kjrofojnjjivsakp")
    public suspend fun dhcpOptionsId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dhcpOptionsId = mapped
    }

    /**
     * @param value The ID of the VPC to which we would like to associate a DHCP Options Set.
     */
    @JvmName("mulucevfnygauyya")
    public suspend fun vpcId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vpcId = mapped
    }

    internal fun build(): VpcDhcpOptionsAssociationArgs = VpcDhcpOptionsAssociationArgs(
        dhcpOptionsId = dhcpOptionsId,
        vpcId = vpcId,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/VpcDhcpOptionsAssociationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin

import com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Provides a VPC DHCP Options Association resource.
 * ## Example Usage
 * <!--Start PulumiCodeChooser -->
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * const dnsResolver = new aws.ec2.VpcDhcpOptionsAssociation("dns_resolver", {
 *     vpcId: fooAwsVpc.id,
 *     dhcpOptionsId: foo.id,
 * });
 * ```
 * ```python
 * import pulumi
 * import pulumi_aws as aws
 * dns_resolver = aws.ec2.VpcDhcpOptionsAssociation("dns_resolver",
 *     vpc_id=foo_aws_vpc["id"],
 *     dhcp_options_id=foo["id"])
 * ```
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using Aws = Pulumi.Aws;
 * return await Deployment.RunAsync(() =>
 * {
 *     var dnsResolver = new Aws.Ec2.VpcDhcpOptionsAssociation("dns_resolver", new()
 *     {
 *         VpcId = fooAwsVpc.Id,
 *         DhcpOptionsId = foo.Id,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/ec2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := ec2.NewVpcDhcpOptionsAssociation(ctx, "dns_resolver", &ec2.VpcDhcpOptionsAssociationArgs{
 * 			VpcId:         pulumi.Any(fooAwsVpc.Id),
 * 			DhcpOptionsId: pulumi.Any(foo.Id),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.ec2.VpcDhcpOptionsAssociation;
 * import com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var dnsResolver = new VpcDhcpOptionsAssociation("dnsResolver", VpcDhcpOptionsAssociationArgs.builder()
 *             .vpcId(fooAwsVpc.id())
 *             .dhcpOptionsId(foo.id())
 *             .build());
 *     }
 * }
 * ```
 * ```yaml
 * resources:
 *   dnsResolver:
 *     type: aws:ec2:VpcDhcpOptionsAssociation
 *     name: dns_resolver
 *     properties:
 *       vpcId: ${fooAwsVpc.id}
 *       dhcpOptionsId: ${foo.id}
 * ```
 * <!--End PulumiCodeChooser -->
 * ## Remarks
 * * You can only associate one DHCP Options Set to a given VPC ID.
 * * Removing the DHCP Options Association automatically sets AWS's `default` DHCP Options Set to the VPC.
 * ## Import
 * Using `pulumi import`, import DHCP associations using the VPC ID associated with the options. For example:
 * ```sh
 * $ pulumi import aws:ec2/vpcDhcpOptionsAssociation:VpcDhcpOptionsAssociation imported vpc-0f001273ec18911b1
 * ```
 * @property dhcpOptionsId The ID of the DHCP Options Set to associate to the VPC.
 * @property vpcId The ID of the VPC to which we would like to associate a DHCP Options Set.
 */
public data class VpcDhcpOptionsAssociationArgs(
    public val dhcpOptionsId: Output<String>? = null,
    public val vpcId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs> {
    override fun toJava(): com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs =
        com.pulumi.aws.ec2.VpcDhcpOptionsAssociationArgs.builder()
            .dhcpOptionsId(dhcpOptionsId?.applyValue({ args0 -> args0 }))
            .vpcId(vpcId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VpcDhcpOptionsAssociationArgs].
 */
@PulumiTagMarker
public class VpcDhcpOptionsAssociationArgsBuilder internal constructor() {
    private var dhcpOptionsId: Output<String>? = null

    private var vpcId: Output<String>? = null

    /**
     * @param value The ID of the DHCP Options Set to associate to the VPC.
     */
    @JvmName("lhovssvkwbbbfigu")
    public suspend fun dhcpOptionsId(`value`: Output<String>) {
        this.dhcpOptionsId = value
    }

    /**
     * @param value The ID of the VPC to which we would like to associate a DHCP Options Set.
     */
    @JvmName("kifdcyacekomayeo")
    public suspend fun vpcId(`value`: Output<String>) {
        this.vpcId = value
    }

    /**
     * @param value The ID of the DHCP Options Set to associate to the VPC.
     */
    @JvmName("jqybjgkpioitgnhv")
    public suspend fun dhcpOptionsId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dhcpOptionsId = mapped
    }

    /**
     * @param value The ID of the VPC to which we would like to associate a DHCP Options Set.
     */
    @JvmName("rhfamyjvgpcqgkct")
    public suspend fun vpcId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vpcId = mapped
    }

    internal fun build(): VpcDhcpOptionsAssociationArgs = VpcDhcpOptionsAssociationArgs(
        dhcpOptionsId = dhcpOptionsId,
        vpcId = vpcId,
    )
}
